/*
** Monte Carlo simulation of auth effects (requires estsimp with xtpcse
** support)
*/
#delimit ;
version 6.0;

/*
** Call _simauth, ticks(obs_to_generate) unpack conf(conf_level)
**      ticks(n) is how many observation b/n auth min and max to generate
**      conf(n)  is the confidence level for the intervals (default 95%)
**      unpack   if this option is specified, predicted vals are unpacked
**               from (assumed) logged form (i.e. newval = exp(predicted)).
**      tenure(n) is the value of tenure to use
**      unemp(n)  is the value of unemp to use
**      interact  if specified, tenure and unemp are interacted with auth
** RETURNS
**      sim_auth with `ticks' observations from min to max
**      sim_exp  expected value of dependent var
**      sim_ciL and sim_ciH: the lower and upper bounds of conf. interval
*/
program define _simauth;
    syntax, TICKS(integer)
            TENURE(real) UNEMP(real) INTERACT
            [UNPACK CONF(integer $S_level)];

    tempvar expvar;

    * calc bounds for conf. intervals;
    loc left = (100-`conf')/2;
    loc right = 100-`left';

    * at least two ticks for end values;
    loc ticks = cond(`ticks'>1,`ticks',2);

    * calc values for auth from ticks;
    qui sum auth;
    loc themin = r(min);
    loc themax = r(max);
    loc thestep = (`themax'-`themin')/(`ticks'-1);

    * generate place-holder variables;
    capture confirm new var sim_auth;
    if _rc == 0 {;
        loc next = `themin'+`thestep';
        qui egen sim_auth = fill(`themin' `next');
        qui replace sim_auth = . if sim_auth > `themax';
        label var sim_auth "Authoritarianism Score";

        qui gen sim_exp = .;
        label var sim_exp "Expected value";
        qui gen sim_ciL = .;
        label var sim_ciL "Lower bound (ci)";
        qui gen sim_ciH = .;
        label var sim_ciH "Upper bound (ci)";
    };

    * predict and stuff into variables;
    setx unemp `unemp' tenure `tenure';
    loc i = 1;
    loc prevpct = 0;
    di _n "% complete: " _c;
    while `i' <= `ticks' {;
        loc percent = int(`i'*100/`ticks');
        if `percent'>=`prevpct'+20 {;
            loc prevpct = `percent';
            di "`percent'.." _c;
        };

        loc auth = min(`themin' + `thestep'*(`i'-1), `themax');
        qui replace sim_auth = `auth' if _n==`i';

        if "`interac'" ~= "" {;
            setx auth `auth' tenaut `tenure'*`auth' unempaut `unemp'*`auth';
        };
        else setx auth `auth';

        simqi, genev(`expvar');
        if "`unpack'" ~= "" {;
            qui replace `expvar' = exp(`expvar');
        };
        su `expvar', meanonly;
        qui replace sim_exp = r(mean) if _n==`i';
        _pctile `expvar', p(`left' `right');
        qui replace sim_ciL = r(r1) if _n==`i';
        qui replace sim_ciH = r(r2) if _n==`i';

        drop `expvar';
        loc i = `i' + 1;
    };
    di "Done";
end;

/*********************************************************************/

drop _all;
set more off;

loc logfn: log;
if "`logfn'" != "" { log close; };

set log linesize 90;
log using simauth, replace;
di "$S_DATE $S_TIME";

loc model1 "auth tenure unemp war gdp87 govfrag ideology";
loc model2 "`model1' eutrade2 fdi";
loc model3 "`model1' tenaut unempaut";
loc model4 "`model3' eutrade2 fdi";

use data, clear;
tsset code year;

loc cnf = 95;
loc tenur_H = 60;
loc tenur_L = 12;
loc unemp_H = 20;
loc unemp_L = 5;

estsimp xtpcse cpiln cpiln_lg `model4', pair genname(bsim);
setx mean;
setx war 0 gdp87 median eutrade2 median fdi median;

_simauth, unpack ticks(30) tenure(24) unemp(10) interact conf(`cnf');
graph sim_ciL sim_ciH sim_exp sim_auth, connect(||l) symbol(iii) noborder
        xlabel(3(1)14) l1title("Predicted CPI (%)") yscale(0,300)
        ylabel(0(100)400) yline(0)
        saving(auth-cpi,replace);

drop bsim*;

estsimp xtpcse gdpdiff gdpd_lg `model4', pair genname(bsim);
setx mean;
setx war 0 gdp87 median eutrade2 median fdi median;

_simauth, ticks(30) tenure(24) unemp(10) interact conf(`cnf');
graph sim_ciL sim_ciH sim_exp sim_auth, connect(||l) symbol(iii) noborder
        xlabel(3(1)14) l1title("Predicted GDP Growth (%)") yscale(-40,0)
        ylabel(-40(10)0) yline(0)
        saving(auth-gdp,replace);

log close;
