/*
** Monte Carlo simulations (requires CLARIFY with xtpcse modification)
*/

#delimit ;
version 6.0;

/*
** Simulates effect of democracy:
**      arg1 = lagged variable
**      years(n): how many years to simulate (each has 1000 obs!)
**      stub(s) : stub name to use for n vars (max 4 chars)
**      conf(n) : confidence level (default is 95%)
**
** NOTE: call after using setx to set approp values; this proc only
**
** simpath cpi_lg, years(20) stub(xy)
*/
program define _simyrs;
    syntax varname , YEARS(integer) STUB(string);

    if length("`stub'") > 4 {;
        di in r "stub name too long (max is 4 chars)";
        exit 198;
    };

    loc lag_var `varlist';
    tempvar evsim;

    loc i = 1;
    while `i' <= `years' {;
        loc prevyr = `i' - 1;

        if `prevyr' > 0 {;  /* already have previous year */
            gen `stub'`i' = -1;  /* generate place-holder */
            loc k = 1;
            loc prevpct = 0;
            di _n "[year " %2.0f `i' "] % complete: 0.." _c;
            while `k' <= _N {;
                loc percent = int(`k'*100/_N);
                if `percent'>=`prevpct'+10 {;
                    loc prevpct = `percent';
                    di "`percent'.." _c;
                };
                setx `lag_var' `stub'`prevyr'[`k'];
                qui simqi, genev(`evsim');
                su `evsim', meanonly;
                qui replace `stub'`i' = r(mean) if _n==`k';
                drop `evsim';
                loc k = `k' + 1;
            };
            di "Done" _c;
        };
        else {; /* first year, just do straight simulation */
            qui simqi, listx genev(`stub'`i');
            di _n "[year " %2.0f 1 "] % complete: 100..Done" _c;
        };

        loc i = `i' + 1;
    };
end;

/*
** this is the wrapper for _simyrs: generate simulations and compute diff.
** runs two simulations, one for low auth and one for high auth, then
** computes cumulative difference in the trajectories
**
** setx all other variables, pass unemp and tenure to this functions
*/
program define simpath;
    syntax varname, YEARS(integer) TENURE(real) UNEMP(real) INICPI(real)
                    [CONF(real $S_level) INTERACT];

    qui sum auth;
    loc minaut = r(min);
    loc maxaut =r(max);

    setx `varlist' `inicpi' tenure `tenure' unemp `unemp' auth `minaut';
    if "`interac'" ~= "" {;
        setx tenaut `tenure'*`minaut' unempaut `unemp'*`minaut';
    };
    _simyrs `varlist', years(`years') stub(L);

    setx `varlist' `inicpi' auth `maxaut';
    if "`interac'" ~= "" {;
        setx tenaut `tenure'*`maxaut' unempaut `unemp'*`maxaut';
    };
    _simyrs `varlist', years(`years') stub(H);      /* high auth */

    capture confirm new variable sim_year;
    if _rc == 0 {;
        qui egen sim_year = fill(0 1);
        qui replace sim_year=. if sim_year >= `years';
        label var sim_year "Years";

        qui gen sim_ciL=.;
        qui gen sim_ciH=.;
        label var sim_ciL "Lower bound (CI)";
        label var sim_ciH "Upper bound (CI)";
    };

    loc left = (100-`conf')/2;
    loc right = 100-`left';

    loc i = 1;
    while `i' <= `years' {;
        * unpack the result and calc difference;
        qui replace L`i' = exp(L`i');
        qui replace H`i' = exp(H`i');
        qui gen diff`i' = L`i' - H`i';

        * calc conf. interval of difference;
        _pctile diff`i', p(`left' `right');
        qui replace sim_ciL = r(r1) if _n==`i';
        qui replace sim_ciH = r(r2) if _n==`i';

        drop L`i' H`i' diff`i';

        loc i = `i' + 1;
    };
end;

/****************************************************************************/

drop _all;
set more off;

loc logfn: log;
if "`logfn'" != "" { log close; };

set log linesize 90;
log using simcpi, replace;
di "$S_DATE $S_TIME";

loc model1 "auth tenure unemp war gdp87 govfrag ideology";
loc model2 "`model1' eutrade2 fdi";
loc model3 "`model1' tenaut unempaut";
loc model4 "`model3' eutrade2 fdi";

use ../data/data, clear;
tsset code year;

loc cnf = 99;
loc inicpi = ln(20);    /* start with inflation of 20% */
loc tenur_H = 60;
loc tenur_L = 12;
loc unemp_H = 20;
loc unemp_L = 4;

estsimp xtpcse cpiln cpiln_lg `model4', pair genname(bsim);
setx mean;
setx war 0 gdp87 median eutrade2 median fdi median;

simpath cpiln_lg, years(10) tenure(`tenur_L') unemp(`unemp_L')
        inicpi(`inicpi') conf(`cnf') interact;
graph sim_ciL sim_ciH sim_year, yline(0) connect(ll) xlabel(0 3 6 9)
        xtick(0 1 2 3 4 5 6 7 8 9) l1title("Change in CPI (%)")
        t1title("Low unemployment, short tenure")
        saving(cpi-tenure-L-unemp-L,replace);

simpath cpiln_lg, years(10) tenure(`tenur_L') unemp(`unemp_H')
        inicpi(`inicpi') conf(`cnf') interact;
graph sim_ciL sim_ciH sim_year, yline(0) connect(ll) xlabel(0 3 6 9)
        xtick(0 1 2 3 4 5 6 7 8 9) l1title("Change in CPI (%)")
        t1title("High unemployment, short tenure")
        saving(cpi-tenure-L-unemp-H,replace);

simpath cpiln_lg, years(10) tenure(`tenur_H') unemp(`unemp_L')
        inicpi(`inicpi') conf(`cnf') interact;
graph sim_ciL sim_ciH sim_year, yline(0) connect(ll) xlabel(0 3 6 9)
        xtick(0 1 2 3 4 5 6 7 8 9) l1title("Change in CPI (%)")
        t1title("Low unemployment, long tenure")
        saving(cpi-tenure-H-unemp-L,replace);

simpath cpiln_lg, years(10) tenure(`tenur_H') unemp(`unemp_H')
        inicpi(`inicpi') conf(`cnf') interact;
graph sim_ciL sim_ciH sim_year, yline(0) connect(ll) xlabel(0 3 6 9)
        xtick(0 1 2 3 4 5 6 7 8 9) l1title("Change in CPI (%)")
        t1title("High unemployment, long tenure")
        saving(cpi-tenure-H-unemp-H,replace);

log close;
