/*
**
** Copyright (c) 1999-2004 Branislav L. Slantchev (slantchev@ucsd.edu)
**
** Monte Carlo simulations (requires CLARIFY with xtpcse modification) of tenure.
**
** Permission is granted to use and modify this file provided changes and their
** authorship are correctly documented. Permission is also granted to distribute
** this file or its modified version if it is necessary for the replication of
** a different study. It is required that the new version acknowledges the use of
** this program with a brief note displayed prominently at the top.
*/

#delimit ;
version 6.0;

/*
** Simulates effect of tenure:
**      gap(n)  : space tenure values in intervals of n between min and max
**                (this means the proc will create 1 + (max-min)/n vars)
**      conf(n) : confidence level (default is 95%)
**      auth(n) : value for auth
**      unemp(n): value for unemp
**      interact: interact terms (default is not to)
**      unpack  : transform predicted variable (predvar=exp(predvar))
**      stub(s) : stub to use for varnames: "stub"_ciL, for example (4 chars max)
**
** NOTE: call after using setx to set other variables!
**
** Returns:
**      sim_ten : with values for tenure b/n min and max in gap increments
**      "stub"_exp : expected value for depvar
**      "stub"_ciL, "stub"_ciH : lower/upper bounds of "conf"% conf. interval
*/
program define _simten;
    syntax , GAP(integer) STUB(string) UNEMP(real) AUTH(real)
             [INTERACT UNPACK CONF(integer $S_level)];

    * check stub;
    if 4 < length("`stub'"){;
        di in r "stub too long (4 chars max)";
        exit 198;
    };

    * calc. number of values to generate b/n min and max in gap length intervals;
    qui su tenure;
    loc tenmin = r(min);
    loc tenmax = r(max);
    loc adder = cond(mod((`tenmax'-`tenmin'),`gap')>0,1,0);
    loc nvals = int((`tenmax'-`tenmin')/`gap') + `adder' + 1;

    * calc bounds of conf. interval;
    loc left = (100-`conf')/2;
    loc right = 100-`left';

    tempvar eval;

    capture confirm new variable sim_ten;
    if _rc == 0 {;
        qui gen sim_ten = .;
        label var sim_ten "Executive Tenure (months)";
        loc stuff = "yes";
    };
    else loc stuff = "no";

    qui gen `stub'_exp = .;
    label var `stub'_exp "Expected value (`stub')";
    qui gen `stub'_ciL = .;
    label var `stub'_ciL "Lower bound (ci)";
    qui gen `stub'_ciH = .;
    label var `stub'_ciH "Upper bound (ci)";

    loc i = 1;
    loc prevpct = 0;
    di _n "% complete: " _c;
    while `i' <= `nvals' {;
        loc percent = int(`i'*100/`nvals');
        if `percent'>=`prevpct'+20 {;
            loc prevpct = `percent';
            di "`percent'.." _c;
        };

        loc tenval = min(`tenmin'+(`i'-1)*`gap',`tenmax');

        if "`stuff'" == "yes" {;
            qui replace sim_ten = `tenval' if _n==`i';
        };

        if "`interac'" ~= "" {;
            setx tenaut `tenval'*`auth' unempaut `unemp'*`auth';
        };
        setx tenure `tenval' auth `auth' unemp `unemp';

        simqi, genev(`eval');
        if "`unpack'" ~= "" {;
            qui replace `eval' = exp(`eval');
        };

        su `eval', meanonly;
        qui replace `stub'_exp = r(mean) if _n==`i';
        _pctile `eval', p(`left',`right');
        qui replace `stub'_ciL = r(r1) if _n==`i';
        qui replace `stub'_ciH = r(r2) if _n==`i';

        drop `eval';
        loc i = `i' + 1;
    };
    di "Done";
end;

/****************************************************************************/

/*
** since plotting both as-is produces an unreadable graph (overlapping)
** do some trickery: extend number of obs to twice current number and
** then "shift" the values for auth a little every other observation
** while eliminating the original obs; for shifted values, set demo to nil.
**
** call after _simten, first() and second() contain the stub() values for
** the two calls to _simten.
** returns s_"first"??? s_"second"??? and s_ten with values ready to graph
*/
program define _shiftit;
    syntax, FIRST(string) SECOND(string);

    loc A = "`first'";
    loc B = "`second'";

    * extend obs. artificially;
    qui count if sim_ten ~= .;
    loc nobs = r(N);

    capture confirm new variable s_ten;
    if _rc == 0 {;
        qui gen s_ten = .;
        label var s_ten "Executive Tenure (Months)";
        qui gen s_`A' = .;
        label var s_`A' "`A' expected value";
        qui gen s_`A'_L = .;
        label var s_`A'_L "`A' lower bound (ci)";
        qui gen s_`A'_H = .;
        label var s_`A'_H "`A' upper bound (ci)";
        qui gen s_`B' = .;
        label var s_`B' "`B' expected value";
        qui gen s_`B'_L = .;
        label var s_`B'_L "`B' lower bound (ci)";
        qui gen s_`B'_H = .;
        label var s_`B'_H "`B' upper bound (ci)";
    };
    else {;
        qui replace s_ten = .;
        qui replace s_`A' = .;
        qui replace s_`A'_L = .;
        qui replace s_`A'_H = .;
        qui replace s_`B' = .;
        qui replace s_`B'_L = .;
        qui replace s_`B'_H = .;
    };

    loc i = 1;
    while `i' <= `nobs' {;
        loc oddrow = `i'*2 - 1;

        * stuff original sim_ten value in odd row and new val in next;
        * then stuff democ in odd rows, and auth in even rows;
        qui replace s_ten = sim_ten[`i'] if _n==`oddrow';
        loc fakeval = sim_ten[`i'] + 1.5;
        qui replace s_ten = `fakeval' if _n==(`oddrow'+1);

        qui replace s_`A' = `A'_exp[`i'] if _n==`oddrow';
        qui replace s_`A'_L = `A'_ciL[`i'] if _n==`oddrow';
        qui replace s_`A'_H = `A'_ciH[`i'] if _n==`oddrow';

        qui replace s_`B' = `B'_exp[`i'] if _n==(`oddrow'+1);
        qui replace s_`B'_L = `B'_ciL[`i'] if _n==(`oddrow'+1);
        qui replace s_`B'_H = `B'_ciH[`i'] if _n==(`oddrow'+1);

        loc i = `i' + 1;
    };
end;

/****************************************************************************/

drop _all;
set more off;

loc logfn: log;
if "`logfn'" != "" { log close; };

set log linesize 90;
log using simtenur, replace;
di "$S_DATE $S_TIME";

loc model1 "auth tenure unemp war gdp87 govfrag ideology";
loc model2 "`model1' eutrade2 fdi";
loc model3 "`model1' tenaut unempaut";
loc model4 "`model3' eutrade2 fdi";

use data, clear;
tsset code year;

loc skip = 6;   /* tenure increases in 6 months intervals */
loc cnf = 95;   /* confidence level */

qui summ auth;
loc maxauth = r(max);
loc minauth = r(min);

estsimp xtpcse cpiln cpiln_lg `model4', pair genname(bsim);
setx mean;
setx war 0 gdp87 median eutrade2 median fdi median;

loc unemp = 4;

_simten, gap(`skip') auth(`maxauth') unemp(`unemp') interact
         stub(auth) unpack conf(`cnf');
_simten, gap(`skip') auth(`minauth') unemp(`unemp') interact
         stub(demo) unpack conf(`cnf');
_shiftit, first(demo) second(auth);

graph s_demo_L s_demo_H s_demo s_auth_L s_auth_H s_auth s_ten,
      connect(||l||l) symbol(ii.ii.)
      xlabel(6(18)118) l1title("Predicted CPI (%)") noborder
      ylabel(0(100)800) t1title("Low unemployment")
      saving(tenure-cpi-unemp-low,replace);

drop auth_* demo_* s_*;
loc unemp = 20;

_simten, gap(`skip') auth(`maxauth') unemp(`unemp') interact
         stub(auth) unpack conf(`cnf');
_simten, gap(`skip') auth(`minauth') unemp(`unemp') interact
         stub(demo) unpack conf(`cnf');
_shiftit, first(demo) second(auth);

graph s_demo_L s_demo_H s_demo s_auth_L s_auth_H s_auth s_ten,
      connect(||l||l) symbol(ii.ii.)
      xlabel(6(18)118) l1title("Predicted CPI (%)") noborder
      ylabel(0(100)300) t1title("High unemployment")
      saving(tenure-cpi-unemp-high,replace);

/***************************************************************/
drop bsim*;
drop auth_* demo_* s_*;

estsimp xtpcse gdpdiff gdpd_lg `model4', pair genname(bsim);
setx mean;
setx war 0 gdp87 median eutrade2 median fdi median;

loc unemp = 4;

_simten, gap(`skip') auth(`maxauth') unemp(`unemp') interact
         stub(auth) conf(`cnf');
_simten, gap(`skip') auth(`minauth') unemp(`unemp') interact
         stub(demo) conf(`cnf');
_shiftit, first(demo) second(auth);

graph s_demo_L s_demo_H s_demo s_auth_L s_auth_H s_auth s_ten,
      connect(||l||l) symbol(ii.ii.)
      xlabel(6(18)118) l1title("Predicted GDP Growth (%)") noborder
      ylabel(-50(10)0) t1title("Low unemployment")
      saving(tenure-gdp-unemp-low,replace);

drop auth_* demo_* s_*;
loc unemp = 20;

_simten, gap(`skip') auth(`maxauth') unemp(`unemp') interact
         stub(auth) conf(`cnf');
_simten, gap(`skip') auth(`minauth') unemp(`unemp') interact
         stub(demo) conf(`cnf');
_shiftit, first(demo) second(auth);

graph s_demo_L s_demo_H s_demo s_auth_L s_auth_H s_auth s_ten,
      connect(||l||l) symbol(ii.ii.)
      xlabel(6(18)118) l1title("Predicted GDP Growth (%)") noborder
      ylabel(-50(10)0) t1title("High unemployment")
      saving(tenure-gdp-unemp-high,replace);

log close;
