/* gendata.do
**
** Copyright (c) 1999-2004 Branislav L. Slantchev (slantchev@ucsd.edu)
**
** Program to generate variables and graphs for the Post-Communist Transitions Project.
**
** Permission is granted to use and modify this file provided changes and their
** authorship are correctly documented. Permission is also granted to distribute
** this file or its modified version if it is necessary for the replication of
** a different study. It is required that the new version acknowledges the use of
** this program with a brief note displayed prominently at the top.
*/
version 6.0
#delimit ;

set more off;
drop _all;
use dataset, clear;

/*
** Label variables that will be used "as is".
*/
label data "Data for Slantchev (2004). Email: slantchev@ucsd.com";
label var country "Country name";
label var scode "Country alpha code";
label var code "Country numeric code";
label var year "Year";
label var govfrag "Government Coalition Fragmentation";
label var war "Intl. or civil war";
label var unemp "Unemployment rate (prev. year)";
label var cpi "Inflation rate";
label var cpi_lg "Inflation rate (prev. year)";
label var prespwr "Presidential power (Hellman-Tucker)";
label var presdur "President tenure (months)";
label var govdur "Cabinet tenure (months)";

label var ssp "Small-scale privatization";
label var prl "Price liberalization";
label var tfe "Trade, foreign exchange";
label var bir "Interest rates, banking";
label var lsp "Large-scale privatization";
label var gvr "Restructuring";
label var cmp "Competition policy";
label var smf "Securities markets";
for var ssp prl tfe bir lsp gvr cmp smf: rename X ebrd_X;

/*
** FHAUTH: Freedom House ranking of authoritarianism
**
** Since Freedom House's Political Liberties and Civil Rights scores
** are low for democracies and high for less free polities. The values
** range from 1 (most free) to 7 (least free), so theoretically, the
** worst authoritarian regime is at 14, while the most democratic is at 2.
*/
gen byte FHauth=pr+cl;
label var FHauth "Authoritarianism (Freedom House)";

/*
** AUTH: Polity IV ranking of democracy/authoritarianism
**
** The authoc/democ variables range from 0 (least) to 10 (most auth/democ).
** The composite score is the difference (autoc-democ), which can theoreically
** range from 10 (most autocratic) to -10 (most democratic).
*/
gen byte auth=p4autoc-p4democ;
label var auth "Authoritarianism (Polity IV)";
drop p4autoc p4democ p4xconst;

/*
** EUTRADE: percentage of EU trade for each country
**
** Imports are usually c.i.f. except for Czech & Slovak Republics, Latvia, and Romania,
** which report them f.o.b. To ensure consistency, import figures for these countries
** are first converted to approximate c.i.f. figures using the standard IMF factor of 1.1
** (i.e. about 10% more for insurance and freight). The percentages are then calculated
** from the totals obtained by adding the import and export figures.
*/
gen byte fob = (scode=="CZR" | scode=="SLO" | scode=="LAT" | scode=="RUM");
replace import = import * 1.1 if fob==1;
replace impeu = impeu * 1.1 if fob==1;
gen eutrade = 100*(impeu+expeu) / (import+export);
label var eutrade "Trade with EU (percent)";
drop fob;

/*
** IDEOLOGY: ideology for the largest party in government
**
** Ideology is important to the extent that it can influence the government. To
** calculate the approximate influence of ideology on government decisions, I
** multiply the partisanship score of the largest party in parliament by the
** percentage of seats it controls (so larger majorities weigh more).
** PARTISAN ranges from -10 (left) to 10 (right). This variable is preferred
** because it underscores the fact that reformers almost never command full
** majorities (unlike leftists), so it's a more conservative estimate.
*/
gen ideology = partisan * seatlar;
label var ideology "Largest govt. party ideology";

/*
** GDPDIFF: percent change in real GDP (GDP87=100%)
** GDP87: real pre-transition GDP, constant 1995 US$ per capita
*/
tsset code year;
replace gdp87 = gdp87/pop87;
replace gdp = gdp/pop;
replace gdp_lg = gdp_lg/pop_lg;
gen gdpdiff = 100*gdp/gdp87 - 100;
gen gdpd_lg = 100*gdp_lg/gdp87 - 100;
label var gdp87 "Real pre-transition GDP (1987,capita)";
label var gdpdiff "Real GDP change (percent,GDP87=100)";
label var gdpd_lg "Lagged real GDP change (GDP87=100)";

/*
** DEBT: total external debt (inc. EDT, IBRD loands, and IDA credits)
*/
gen debt = (edt+ibrd)/pop;
label var debt "Total external debt (capita)";

/*
** ODA: total official development assistance US$ per capita
*/
replace oda = oda/pop;
label var oda "Development assistance (capita)";

/*
** FDI: foreign direct investment US$ per capita
*/
replace fdi = fdi/pop;
label var fdi "Foreign direct investment (capita)";

/*
** EUTRADE2: get reasonable values for eutrade 1999: mean diff. of last 3 years + 1998 value
*/
tsset code year, yearly;
gen eudiff = eutrade - L.eutrade;
egen eudiffav = mean(eudiff) if year>=1996, by(code);
gen eutrade2 = eutrade;
sort code year;
replace eutrade2 = L.eutrade2 + eudiffav if eutrade==.;
drop eudiff*;
label var eutrade2 "Trade with EU (percent,1999 est)";

/*
** TENURE: executive tenure (president if SYSTYPE==presidential, cabinet if
**          SYSTYPE==parliamentary; average of the two if SYSTYPE==mixed)
** SYSTYPE: system type 1 (parliamentary), 2 (mixed), or 3 (presidential)
**          importance of presidency determined by dividing formal presidential
**          powers by maximum in the set; pres. system coded if that result is
**          greater than or equal to .4; parliamentary system coded if that
**          result is less than or equal to .2; mixed system otherwise.
*/
qui summ prespwr;
local presmax = r(max);
gen preswgt = prespwr/`presmax';
gen byte ispre = preswgt >= .4;
gen byte ispar = preswgt <= .2;
gen byte ismix = ~ispre & ~ispar;
gen tenure = ispre*presdur + ispar*govdur + ismix*((presdur+govdur)/2);
gen systype = 1*ispar + 2*ismix + 3*ispre;
drop preswgt ispre ispar ismix;

label def stlab 1 "Parliamentary" 2 "Mixed" 3 "Presidential";
label val systype stlab;
label var systype "System Type";
label var tenure "Executive tenure (months)";

/*
** STABIL: low/med/adv in stabilization (short-term) reforms
** STRUCT: low/med/adv in structural adjustment (long-term) reforms
*/
gen stab = ebrd_ssp+ebrd_prl+ebrd_tfe+ebrd_bir;
qui summ stab;
loc se = sqrt(r(Var));
gen stab_low = stab<=round(r(min)+`se',1) if stab~=.;
gen stab_adv = stab>=round(r(max)-`se',1) if stab~=.;
gen stab_med = 1 - (stab_low + stab_adv) if stab~=.;
gen stabil = 1*stab_low + 2*stab_med + 3*stab_adv - 1 if stab~=.;
drop stab_* stab;

gen stru = ebrd_lsp+ebrd_gvr+ebrd_cmp+ebrd_smf;
qui summ stru;
loc se = sqrt(r(Var));
gen stru_low = stru<=round(r(min)+`se',1) if stru~=.;
gen stru_adv = stru>=round(r(max)-`se',1) if stru~=.;
gen stru_med = 1 - (stru_low + stru_adv) if stru~=.;
gen struct = 1*stru_low + 2*stru_med + 3*stru_adv - 1 if stru~=.;
drop stru_* stru;

label def reflab 0 "Low" 1 "Medium" 2 "Advanced";
label var stabil "Short time-horizon reforms";
label val stabil reflab;
label var struct "Long time-horizon reforms";
label val struct reflab;

pwcorr struct stabil, star(.01);

/*
** INTERACTION EFFECTS
**      TENAUT: tenure-authoritarianism interaction; executive
**      UNEMPAUT: unemployment and authoritarianism interaction
*/
gen tenaut = tenure * auth;
gen unempaut = unemp * auth;
label var tenaut "Interact: tenure-auth";
label var unempaut "Interact: unemployment-auth";

gen FHtenaut = tenure * FHauth;
gen FHunempaut = unemp * FHauth;
label var FHtenaut "Interact: tenure-auth (Freedom House)";
label var FHunempaut "Interact: unemployment-auth (Freedom House)";

/*
** Transform CPI and CPI_LG
*/
gen cpiln = ln(cpi);
gen cpiln_lg = ln(cpi_lg);
label var cpiln "Inflation rate (natural log)";
label var cpiln_lg "Inflation rate (prev.year, ln)";

/*
** Drop unnecessary variables
*/
drop import export impeu expeu gdp gdp_lg pop* edt ibrd resrv seatlar
        partisan pr cl frye;
drop if year<=1992 & scode=="SLO";  /* only Czech Rep. data for Czechoslovakia */
drop if year==1991 & scode=="MAC";  /* too much missingness for Macedonia 1991 */

sort country year;
save data, replace;
